@@ -8,9 +8,9 @@
  */
 
 /** Load WordPress Administration Bootstrap */
-require_once( dirname( __FILE__ ) . '/admin.php' );
+require_once __DIR__ . '/admin.php';
 
-require_once( ABSPATH . WPINC . '/http.php' );
+require_once ABSPATH . WPINC . '/http.php';
 
 $title       = __( 'Upgrade Network' );
 $parent_file = 'upgrade.php';
@@ -28,11 +28,11 @@ get_current_screen()->add_help_tab(
 
 get_current_screen()->set_help_sidebar(
 	'<p><strong>' . __( 'For more information:' ) . '</strong></p>' .
-	'<p>' . __( '<a href="https://codex.wordpress.org/Network_Admin_Updates_Screen">Documentation on Upgrade Network</a>' ) . '</p>' .
+	'<p>' . __( '<a href="https://wordpress.org/support/article/network-admin-updates-screen/">Documentation on Upgrade Network</a>' ) . '</p>' .
 	'<p>' . __( '<a href="https://wordpress.org/support/">Support</a>' ) . '</p>'
 );
 
-require_once( ABSPATH . 'wp-admin/admin-header.php' );
+require_once ABSPATH . 'wp-admin/admin-header.php';
 
 if ( ! current_user_can( 'upgrade_network' ) ) {
 	wp_die( __( 'Sorry, you are not allowed to access this page.' ), 403 );
@@ -49,7 +49,7 @@ switch ( $action ) {
 
 		if ( $n < 5 ) {
 			/**
-			 * @global string $wp_db_version
+			 * @global int $wp_db_version WordPress database version.
 			 */
 			global $wp_db_version;
 			update_site_option( 'wpmu_upgrade_site', $wp_db_version );
@@ -90,10 +90,11 @@ switch ( $action ) {
 					'sslverify'   => false,
 				)
 			);
+
 			if ( is_wp_error( $response ) ) {
 				wp_die(
 					sprintf(
-						/* translators: 1: site url, 2: server error message */
+						/* translators: 1: Site URL, 2: Server error message. */
 						__( 'Warning! Problem updating %1$s. Your server may not be able to connect to sites running on it. Error message: %2$s' ),
 						$siteurl,
 						'<em>' . $response->get_error_message() . '</em>'
@@ -109,6 +110,7 @@ switch ( $action ) {
 			 * @param array|WP_Error $response The upgrade response array or WP_Error on failure.
 			 */
 			do_action( 'after_mu_upgrade', $response );
+
 			/**
 			 * Fires after each site has been upgraded.
 			 *
@@ -132,7 +134,7 @@ switch ( $action ) {
 		break;
 	case 'show':
 	default:
-		if ( get_site_option( 'wpmu_upgrade_site' ) != $GLOBALS['wp_db_version'] ) :
+		if ( (int) get_site_option( 'wpmu_upgrade_site' ) !== $GLOBALS['wp_db_version'] ) :
 			?>
 		<h2><?php _e( 'Database Update Required' ); ?></h2>
 		<p><?php _e( 'WordPress has been updated! Before we send you on your way, we need to individually upgrade the sites in your network.' ); ?></p>
@@ -152,4 +154,4 @@ switch ( $action ) {
 ?>
 </div>
 
-<?php include( ABSPATH . 'wp-admin/admin-footer.php' ); ?>
+<?php require_once ABSPATH . 'wp-admin/admin-footer.php'; ?>
