@@ -74,7 +74,7 @@ class WP_Metadata_Lazyloader {
 	 */
 	public function queue_objects( $object_type, $object_ids ) {
 		if ( ! isset( $this->settings[ $object_type ] ) ) {
-			return new WP_Error( 'invalid_object_type', __( 'Invalid object type' ) );
+			return new WP_Error( 'invalid_object_type', __( 'Invalid object type.' ) );
 		}
 
 		$type_settings = $this->settings[ $object_type ];
@@ -114,7 +114,7 @@ class WP_Metadata_Lazyloader {
 	 */
 	public function reset_queue( $object_type ) {
 		if ( ! isset( $this->settings[ $object_type ] ) ) {
-			return new WP_Error( 'invalid_object_type', __( 'Invalid object type' ) );
+			return new WP_Error( 'invalid_object_type', __( 'Invalid object type.' ) );
 		}
 
 		$type_settings = $this->settings[ $object_type ];
