@@ -10,4 +10,4 @@
 
 _deprecated_file( basename( __FILE__ ), '4.5.0', 'wp-includes/theme-compat/embed.php' );
 
-include( ABSPATH . WPINC . '/theme-compat/embed.php' );
+require ABSPATH . WPINC . '/theme-compat/embed.php';
