@@ -1,4 +1,10 @@
-var wpAjax = jQuery.extend( {
+/**
+ * @output wp-includes/js/wp-ajax-response.js
+ */
+
+ /* global wpAjax */
+
+window.wpAjax = jQuery.extend( {
 	unserialize: function( s ) {
 		var r = {}, q, pp, i, p;
 		if ( !s ) { return r; }
@@ -11,10 +17,10 @@ var wpAjax = jQuery.extend( {
 		}
 		return r;
 	},
-	parseAjaxResponse: function( x, r, e ) { // 1 = good, 0 = strange (bad data?), -1 = you lack permission
+	parseAjaxResponse: function( x, r, e ) { // 1 = good, 0 = strange (bad data?), -1 = you lack permission.
 		var parsed = {}, re = jQuery('#' + r).empty(), err = '';
 
-		if ( x && typeof x == 'object' && x.getElementsByTagName('wp_ajax') ) {
+		if ( x && typeof x === 'object' && x.getElementsByTagName('wp_ajax') ) {
 			parsed.responses = [];
 			parsed.errors = false;
 			jQuery('response', x).each( function() {
@@ -45,7 +51,7 @@ var wpAjax = jQuery.extend( {
 		}
 		if ( isNaN(x) ) { return !re.html('<div class="error"><p>' + x + '</p></div>'); }
 		x = parseInt(x,10);
-		if ( -1 == x ) { return !re.html('<div class="error"><p>' + wpAjax.noPerm + '</p></div>'); }
+		if ( -1 === x ) { return !re.html('<div class="error"><p>' + wpAjax.noPerm + '</p></div>'); }
 		else if ( 0 === x ) { return !re.html('<div class="error"><p>' + wpAjax.broken  + '</p></div>'); }
 		return true;
 	},
@@ -56,9 +62,9 @@ var wpAjax = jQuery.extend( {
 		selector = jQuery( selector );
 		return !wpAjax.invalidateForm( selector.find('.form-required').filter( function() { return jQuery('input:visible', this).val() === ''; } ) ).length;
 	}
-}, wpAjax || { noPerm: 'Sorry, you are not allowed to do that.', broken: 'An unidentified error has occurred.' } );
+}, wpAjax || { noPerm: 'Sorry, you are not allowed to do that.', broken: 'Something went wrong.' } );
 
-// Basic form validation
+// Basic form validation.
 jQuery(document).ready( function($){
 	$('form.validate').submit( function() { return wpAjax.validateForm( $(this) ); } );
 });
